@@ -139,7 +139,10 @@ Bool wcmIsAValidType(InputInfoPtr pInfo, const char* type)
 	char* dsource = xf86CheckStrOption(pInfo->options, "_source", "");
 
 	if (!type)
+	{
+		xf86Msg(X_ERROR, "%s: No type specified\n", pInfo->name);
 		return FALSE;
+	}
 
 	/* walkthrough all types */
 	for (j = 0; j < ARRAY_SIZE(wcmType); j++)
@@ -169,6 +172,11 @@ Bool wcmIsAValidType(InputInfoPtr pInfo, const char* type)
 			}
 		}
 	}
+
+	if (!ret)
+		xf86Msg(X_ERROR, "%s: Invalid type '%s' for this device.\n",
+			pInfo->name, type);
+
 	return ret;
 }
 
@@ -183,8 +191,8 @@ int wcmDeviceTypeKeys(InputInfoPtr pInfo)
 
 	switch (priv->common->tablet_id)
 	{
-		case 0xCC:  /* CintiqV5 */
-			priv->common->tablet_type = WCM_LCD;
+		case 0xF4:  /* Cintiq 24HD */
+			TabletSetFeature(priv->common, WCM_DUALRING);
 			/* fall through */
 
 		case 0xB8:  /* I4 */
@@ -193,13 +201,13 @@ int wcmDeviceTypeKeys(InputInfoPtr pInfo)
 		case 0xBB:  /* I4 */
 		case 0xBC:  /* I4 */
 		case 0xBD:  /* I4 */
-			priv->common->tablet_type = WCM_ROTATION;
+			TabletSetFeature(priv->common, WCM_ROTATION);
 			/* fall through */
 
 		/* tablets with touch ring */
 		case 0x17:  /* BambooFun */
 		case 0x18:  /* BambooFun */
-			priv->common->tablet_type |= WCM_RING;
+			TabletSetFeature(priv->common, WCM_RING);
 			break;
 
 		/* tablets support dual input */
@@ -214,7 +222,7 @@ int wcmDeviceTypeKeys(InputInfoPtr pInfo)
 		case 0x44:  /* I2 */
 		case 0x45:  /* I2 */
 		case 0x47:  /* I2 */
-			priv->common->tablet_type = WCM_DUALINPUT;
+			TabletSetFeature(priv->common, WCM_DUALINPUT);
 			break;
 
 		/* P4 display tablets */
@@ -233,14 +241,15 @@ int wcmDeviceTypeKeys(InputInfoPtr pInfo)
 		case 0xC7:  /* DTU1931 */
 		case 0xCE:  /* DTU2231 */
 		case 0xF0:  /* DTU1631 */
-			priv->common->tablet_type |= WCM_LCD;
+			TabletSetFeature(priv->common, WCM_LCD);
 			break;
 
 		/* tablets support menu strips */
 		case 0x3F:  /* CintiqV5 */
 		case 0xC5:  /* CintiqV5 */
 		case 0xC6:  /* CintiqV5 */
-			priv->common->tablet_type = WCM_LCD;
+		case 0xCC:  /* CinitqV5 */
+			TabletSetFeature(priv->common, WCM_LCD);
 			/* fall through */
 		case 0xB0:  /* I3 */
 		case 0xB1:  /* I3 */
@@ -249,35 +258,34 @@ int wcmDeviceTypeKeys(InputInfoPtr pInfo)
 		case 0xB4:  /* I3 */
 		case 0xB5:  /* I3 */
 		case 0xB7:  /* I3 */
-			priv->common->tablet_type |= WCM_STRIP | WCM_ROTATION;
+			TabletSetFeature(priv->common, WCM_STRIP | WCM_ROTATION);
 			break;
 
 		case 0xE2: /* TPC with 2FGT */
 		case 0xE3: /* TPC with 2FGT */
 		case 0xE6: /* TPC with 2FGT */
-			priv->common->tablet_type = WCM_TPC;
-			priv->common->tablet_type |= WCM_LCD;
+			TabletSetFeature(priv->common, WCM_TPC);
 			break;
 
 		case 0x93: /* TPC with 1FGT */
 		case 0x9A: /* TPC with 1FGT */
 		case 0x90: /* TPC */
-			priv->common->tablet_type |= WCM_TPC;
-			priv->common->tablet_type |= WCM_LCD;
+		case 0x97: /* TPC */
+			TabletSetFeature(priv->common, WCM_TPC);
 			break;
 
 		case 0x9F:
-			priv->common->tablet_type |= WCM_LCD;
+			TabletSetFeature(priv->common, WCM_LCD);
 			break;
 	}
 
 	if (ISBITSET(common->wcmKeys, BTN_TOOL_PEN))
-		priv->common->tablet_type |= WCM_PEN;
+		TabletSetFeature(priv->common, WCM_PEN);
 
 	if (ISBITSET (common->wcmKeys, BTN_0) ||
 			ISBITSET (common->wcmKeys, BTN_FORWARD))
 	{
-		priv->common->tablet_type |= WCM_PAD;
+		TabletSetFeature(priv->common, WCM_PAD);
 	}
 
 	/* This handles both protocol 4 and 5 meanings of wcmKeys */
@@ -286,9 +294,9 @@ int wcmDeviceTypeKeys(InputInfoPtr pInfo)
 		/* TRIPLETAP means 2 finger touch */
 		/* DOUBLETAP without TRIPLETAP means 1 finger touch */
 		if (ISBITSET(common->wcmKeys, BTN_TOOL_TRIPLETAP))
-			priv->common->tablet_type |= WCM_2FGT;
+			TabletSetFeature(priv->common, WCM_2FGT);
 		else if (ISBITSET(common->wcmKeys, BTN_TOOL_DOUBLETAP))
-			priv->common->tablet_type |= WCM_1FGT;
+			TabletSetFeature(priv->common, WCM_1FGT);
 	}
 
 	if (common->wcmProtocolLevel == WCM_PROTOCOL_GENERIC)
@@ -296,21 +304,57 @@ int wcmDeviceTypeKeys(InputInfoPtr pInfo)
 		/* DOUBLETAP means 2 finger touch */
 		/* FINGER without DOUBLETAP means 1 finger touch */
 		if (ISBITSET(common->wcmKeys, BTN_TOOL_DOUBLETAP))
-			priv->common->tablet_type |= WCM_2FGT;
+			TabletSetFeature(priv->common, WCM_2FGT);
 		else if (ISBITSET(common->wcmKeys, BTN_TOOL_FINGER))
-			priv->common->tablet_type |= WCM_1FGT;
+			TabletSetFeature(priv->common, WCM_1FGT);
 	}
 
 	return ret;
 }
 
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) < 14
+static InputOption*
+input_option_new(InputOption *list, char *key, char *value)
+{
+	InputOption *new;
+
+	new = calloc(1, sizeof(InputOption));
+	new->key = key;
+	new->value = value;
+	new->next = list;
+	return new;
+}
+
+static void
+input_option_free_list(InputOption **opts)
+{
+	InputOption *tmp = *opts;
+	while(*opts)
+	{
+		tmp = (*opts)->next;
+		free((*opts)->key);
+		free((*opts)->value);
+		free((*opts));
+		*opts = tmp;
+	}
+}
+#endif
+
 /**
  * Duplicate xf86 options, replace the "type" option with the given type
- * (and the name with "$name $type" and convert them to InputOption */
-static InputOption *wcmOptionDupConvert(InputInfoPtr pInfo, const char* basename, const char *type)
+ * (and the name with "$name $type" and convert them to InputOption
+ *
+ * @param basename Kernel device name for this device
+ * @param type Tool type (cursor, eraser, etc.)
+ * @param serial Serial number this device should be bound to (-1 for "any")
+ */
+static InputOption *wcmOptionDupConvert(InputInfoPtr pInfo, const char* basename, const char *type, int serial)
 {
+	WacomDevicePtr priv = pInfo->private;
+	WacomCommonPtr common = priv->common;
 	pointer original = pInfo->options;
-	InputOption *iopts = NULL, *new;
+	WacomToolPtr ser = common->serials;
+	InputOption *iopts = NULL;
 	char *name;
 	pointer options;
 	int rc;
@@ -326,40 +370,40 @@ static InputOption *wcmOptionDupConvert(InputInfoPtr pInfo, const char* basename
 		options = dummy.options;
 	}
 #endif
+	if (serial > -1)
+	{
+		while (ser->serial && ser->serial != serial)
+			ser = ser->next;
+
+		if (strlen(ser->name) > 0)
+			rc = asprintf(&name, "%s %s %s", basename, ser->name, type);
+		else
+			rc = asprintf(&name, "%s %d %s", basename, ser->serial, type);
+	}
+	else
+		rc = asprintf(&name, "%s %s", basename, type);
 
-	rc = asprintf(&name, "%s %s", basename, type);
 	if (rc == -1) /* if asprintf fails, strdup will probably too... */
 		name = strdup("unknown");
 
 	options = xf86ReplaceStrOption(options, "Type", type);
 	options = xf86ReplaceStrOption(options, "Name", name);
+
+	if (serial > -1)
+		options = xf86ReplaceIntOption(options, "Serial", ser->serial);
+
 	free(name);
 
 	while(options)
 	{
-		new = calloc(1, sizeof(InputOption));
-
-		new->key = xf86OptionName(options);
-		new->value = xf86OptionValue(options);
-		new->next = iopts;
-		iopts = new;
+		iopts = input_option_new(iopts,
+					 xf86OptionName(options),
+					 xf86OptionValue(options));
 		options = xf86NextOption(options);
 	}
 	return iopts;
 }
 
-static void wcmFreeInputOpts(InputOption* opts)
-{
-	InputOption *tmp = opts;
-	while(opts)
-	{
-		tmp = opts->next;
-		free(opts->key);
-		free(opts->value);
-		free(opts);
-		opts = tmp;
-	}
-}
 
 #if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 11
 /**
@@ -411,7 +455,7 @@ wcmHotplugDevice(ClientPtr client, pointer closure )
 			      hotplug_info->attrs,
 #endif
 			      &dev);
-	wcmFreeInputOpts(hotplug_info->input_options);
+	input_option_free_list(&hotplug_info->input_options);
 
 #if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 11
 	FreeInputAttributes(hotplug_info->attrs);
@@ -435,8 +479,9 @@ wcmHotplugDevice(ClientPtr client, pointer closure )
  * @param pInfo The parent device
  * @param basename The base name for the device (type will be appended)
  * @param type Type name for this tool
+ * @param serial Serial number this device should be bound to (-1 for "any")
  */
-static void wcmQueueHotplug(InputInfoPtr pInfo, const char* basename, const char *type)
+static void wcmQueueHotplug(InputInfoPtr pInfo, const char* basename, const char *type, int serial)
 {
 	WacomHotplugInfo *hotplug_info;
 
@@ -448,20 +493,50 @@ static void wcmQueueHotplug(InputInfoPtr pInfo, const char* basename, const char
 		return;
 	}
 
-	hotplug_info->input_options = wcmOptionDupConvert(pInfo, basename, type);
+	hotplug_info->input_options = wcmOptionDupConvert(pInfo, basename, type, serial);
 #if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 11
 	hotplug_info->attrs = wcmDuplicateAttributes(pInfo, type);
 #endif
 	QueueWorkProc(wcmHotplugDevice, serverClient, hotplug_info);
 }
 
+/**
+ * Hotplug all serial numbers configured on this device.
+ *
+ * @param basename The kernel device name
+ */
+static void wcmHotplugSerials(InputInfoPtr pInfo, const char *basename)
+{
+	WacomDevicePtr  priv = (WacomDevicePtr)pInfo->private;
+	WacomCommonPtr  common = priv->common;
+	WacomToolPtr    ser = common->serials;
+
+	while (ser)
+	{
+		xf86Msg(X_INFO, "%s: hotplugging serial %d.\n", pInfo->name, ser->serial);
+
+		if (wcmIsAValidType(pInfo, "stylus") &&
+		    (ser->typeid & STYLUS_ID))
+			wcmQueueHotplug(pInfo, basename, "stylus", ser->serial);
+
+		if (wcmIsAValidType(pInfo, "eraser") &&
+		    (ser->typeid & ERASER_ID))
+			wcmQueueHotplug(pInfo, basename, "eraser", ser->serial);
+
+		if (wcmIsAValidType(pInfo, "cursor") &&
+		    (ser->typeid & CURSOR_ID))
+			wcmQueueHotplug(pInfo, basename, "cursor", ser->serial);
+
+		ser = ser->next;
+	}
+}
+
 void wcmHotplugOthers(InputInfoPtr pInfo, const char *basename)
 {
 	int i, skip = 1;
-	char*		device;
 
-        xf86Msg(X_INFO, "%s: hotplugging dependent devices.\n", pInfo->name);
-	device = xf86SetStrOption(pInfo->options, "Device", NULL);
+	xf86Msg(X_INFO, "%s: hotplugging dependent devices.\n", pInfo->name);
+
         /* same loop is used to init the first device, if we get here we
          * need to start at the second one */
 	for (i = 0; i < ARRAY_SIZE(wcmType); i++)
@@ -471,9 +546,12 @@ void wcmHotplugOthers(InputInfoPtr pInfo, const char *basename)
 			if (skip)
 				skip = 0;
 			else
-				wcmQueueHotplug(pInfo, basename, wcmType[i].type);
+				wcmQueueHotplug(pInfo, basename, wcmType[i].type, -1);
 		}
 	}
+
+	wcmHotplugSerials(pInfo, basename);
+
         xf86Msg(X_INFO, "%s: hotplugging completed.\n", pInfo->name);
 }
 
@@ -521,8 +599,92 @@ int wcmNeedAutoHotplug(InputInfoPtr pInfo, const char **type)
 	return 1;
 }
 
+int wcmParseSerials (InputInfoPtr pInfo)
+{
+	WacomDevicePtr  priv = (WacomDevicePtr)pInfo->private;
+	WacomCommonPtr  common = priv->common;
+	char            *s;
+
+	if (common->serials)
+	{
+		return 0; /*Parse has been already done*/
+	}
+
+	s = xf86SetStrOption(pInfo->options, "ToolSerials", NULL);
+	if (s) /*Dont parse again, if the commons have values already*/
+	{
+		char* tok = strtok(s, ";");
+		while (tok != NULL)
+		{
+			int serial, nmatch;
+			char type[strlen(tok) + 1];
+			char name[strlen(tok) + 1];
+			WacomToolPtr ser = calloc(1, sizeof(WacomTool));
+
+			if (ser == NULL)
+				return 1;
+
+			nmatch = sscanf(tok,"%d,%[a-z],%[A-Za-z ]",&serial, type, name);
+
+			if (nmatch < 1)
+			{
+				xf86Msg(X_ERROR, "%s: %s is invalid serial string.\n",
+					pInfo->name, tok);
+				return 1;
+			}
+
+			if (nmatch >= 1)
+			{
+				xf86Msg(X_CONFIG, "%s: Tool serial %d found.\n",
+					pInfo->name, serial);
+
+				ser->serial = serial;
+
+				ser->typeid = STYLUS_ID | ERASER_ID; /*Default to both tools*/
+			}
+
+			if (nmatch >= 2)
+			{
+				xf86Msg(X_CONFIG, "%s: Tool %d has type %s.\n",
+					pInfo->name, serial, type);
+				if ((strcmp(type, "pen") == 0) || (strcmp(type, "airbrush") == 0))
+					ser->typeid = STYLUS_ID | ERASER_ID;
+				else if (strcmp(type, "artpen") == 0)
+					ser->typeid = STYLUS_ID;
+				else if (strcmp(type, "cursor") == 0)
+					ser->typeid = CURSOR_ID;
+				else    xf86Msg(X_CONFIG, "%s: Invalid type %s, defaulting to pen.\n",
+					pInfo->name, type);
+			}
+
+			if (nmatch == 3)
+			{
+				xf86Msg(X_CONFIG, "%s: Tool %d is named %s.\n",
+					pInfo->name, serial, name);
+				ser->name = strdup(name);
+			}
+			else ser->name = ""; /*no name yet*/
+
+			if (common->serials == NULL)
+				common->serials = ser;
+			else
+			{
+				WacomToolPtr tool = common->serials;
+				while (tool->next)
+					tool = tool->next;
+				tool->next = ser;
+			}
+
+			tok = strtok(NULL,";");
+		}
+	}
+	return 0;
+}
+
 /**
- * Parse the options for this device.
+ * Parse the pre-init options for this device. Most useful for options
+ * needed to properly init a device (baud rate for example).
+ *
  * Note that parameters is_primary and is_dependent are mutually exclusive,
  * though both may be false in the case of an xorg.conf device.
  *
@@ -532,7 +694,8 @@ int wcmNeedAutoHotplug(InputInfoPtr pInfo, const char **type)
  * otherwise.
  * @retvalue True on success or False otherwise.
  */
-Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
+Bool wcmPreInitParseOptions(InputInfoPtr pInfo, Bool is_primary,
+			    Bool is_dependent)
 {
 	WacomDevicePtr  priv = (WacomDevicePtr)pInfo->private;
 	WacomCommonPtr  common = priv->common;
@@ -542,10 +705,6 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 	int		tpc_button_is_on;
 
 	/* Optional configuration */
-	priv->debugLevel = xf86SetIntOption(pInfo->options,
-					    "DebugLevel", priv->debugLevel);
-	common->debugLevel = xf86SetIntOption(pInfo->options,
-					      "CommonDBG", common->debugLevel);
 	s = xf86SetStrOption(pInfo->options, "Mode", NULL);
 
 	if (s && (xf86NameCmp(s, "absolute") == 0))
@@ -570,8 +729,8 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 	 */
 	if (IsPad(priv))
 	{
-		priv->wheelup = 4;
-		priv->wheeldn = 5;
+		priv->wheelup = priv->wheel2up = 4;
+		priv->wheeldn = priv->wheel2dn = 5;
 		set_absolute(pInfo, TRUE);
 	}
 
@@ -579,7 +738,7 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 
 	if (s)
 	{
-		int rotation;
+		int rotation = ROTATE_NONE;
 
 		if (xf86NameCmp(s, "CW") == 0)
 			rotation = ROTATE_CW;
@@ -631,7 +790,7 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 	 * Slightly raised curve might be 0,5,95,100
 	 */
 	s = xf86SetStrOption(pInfo->options, "PressCurve", "0,0,100,100");
-	if (s && (IsStylus(priv) || IsEraser(priv)))
+	if (s && (IsPen(priv) || IsTouch(priv)))
 	{
 		int a,b,c,d;
 		if ((sscanf(s,"%d,%d,%d,%d",&a,&b,&c,&d) != 4) ||
@@ -642,6 +801,10 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 			wcmSetPressureCurve(priv,a,b,c,d);
 	}
 
+	/*Serials of tools we want hotpluged*/
+	if (wcmParseSerials (pInfo) != 0)
+		goto error;
+
 	if (IsCursor(priv))
 	{
 		common->wcmCursorProxoutDist = xf86SetIntOption(pInfo->options, "CursorProx", 0);
@@ -688,8 +851,6 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 	common->wcmThreshold = xf86SetIntOption(pInfo->options, "Threshold",
 			common->wcmThreshold);
 
-	common->wcmMaxZ = xf86SetIntOption(pInfo->options, "MaxZ",
-					   common->wcmMaxZ);
 	if (xf86SetBoolOption(pInfo->options, "ButtonsOnly", 0))
 		priv->flags |= BUTTONS_ONLY_FLAG;
 
@@ -707,7 +868,7 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 	if (TabletHasFeature(common, WCM_1FGT) ||
 	    TabletHasFeature(common, WCM_2FGT))
 	{
-		int touch_is_on, capacity_is_on;
+		int touch_is_on;
 
 		/* TouchDefault was off for all devices
 		 * except when touch is supported */
@@ -721,15 +882,6 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 		else if (touch_is_on != common->wcmTouch)
 			xf86Msg(X_WARNING, "%s: Touch option can only be set "
 				"by a touch tool.\n", pInfo->name);
-
-		capacity_is_on = xf86SetBoolOption(pInfo->options, "Capacity",
-						   common->wcmCapacityDefault);
-
-		if (is_primary || IsTouch(priv))
-			common->wcmCapacity = capacity_is_on;
-		else if (capacity_is_on != common->wcmCapacity)
-			xf86Msg(X_WARNING, "%s: Touch Capacity option can only be"
-				"set by a touch tool.\n", pInfo->name);
 	}
 
 	/* 2FG touch device */
@@ -750,17 +902,9 @@ Bool wcmParseOptions(InputInfoPtr pInfo, Bool is_primary, Bool is_dependent)
 			xf86Msg(X_WARNING, "%s: Touch gesture option can only "
 				"be set by a touch tool.\n", pInfo->name);
 
-		common->wcmGestureParameters.wcmZoomDistance =
-			xf86SetIntOption(pInfo->options, "ZoomDistance",
-			common->wcmGestureParameters.wcmZoomDistanceDefault);
-
-		common->wcmGestureParameters.wcmScrollDistance =
-			xf86SetIntOption(pInfo->options, "ScrollDistance",
-			common->wcmGestureParameters.wcmScrollDistanceDefault);
-
 		common->wcmGestureParameters.wcmTapTime =
 			xf86SetIntOption(pInfo->options, "TapTime",
-			common->wcmGestureParameters.wcmTapTimeDefault);
+			common->wcmGestureParameters.wcmTapTime);
 	}
 
 	/* Swap stylus buttons 2 and 3 for Tablet PCs */
@@ -787,4 +931,57 @@ error:
 	return FALSE;
 }
 
+/* The values were based on trail and error. */
+#define WCM_BAMBOO3_MAXX 4096.0
+#define WCM_BAMBOO3_ZOOM_DISTANCE 180.0
+#define WCM_BAMBOO3_SCROLL_DISTANCE 80.0
+#define WCM_BAMBOO3_SCROLL_SPREAD_DISTANCE 350.0
+
+/**
+ * Parse post-init options for this device. Useful for overriding HW
+ * specific options computed during init phase (HW distances for example).
+ *
+ * Note that parameters is_primary and is_dependent are mutually exclusive,
+ * though both may be false in the case of an xorg.conf device.
+ *
+ * @param is_primary True if the device is the parent device for
+ * hotplugging, False if the device is a depent or xorg.conf device.
+ * @param is_hotplugged True if the device is a dependent device, FALSE
+ * otherwise.
+ * @retvalue True on success or False otherwise.
+ */
+Bool wcmPostInitParseOptions(InputInfoPtr pInfo, Bool is_primary,
+			     Bool is_dependent)
+{
+	WacomDevicePtr  priv = (WacomDevicePtr)pInfo->private;
+	WacomCommonPtr  common = priv->common;
+
+	common->wcmMaxZ = xf86SetIntOption(pInfo->options, "MaxZ",
+					   common->wcmMaxZ);
+
+	/* 2FG touch device */
+	if (TabletHasFeature(common, WCM_2FGT) && IsTouch(priv))
+	{
+		int zoom_distance = common->wcmMaxTouchX *
+			(WCM_BAMBOO3_ZOOM_DISTANCE / WCM_BAMBOO3_MAXX);
+		int scroll_distance = common->wcmMaxTouchX *
+			(WCM_BAMBOO3_SCROLL_DISTANCE / WCM_BAMBOO3_MAXX);
+
+		common->wcmGestureParameters.wcmZoomDistance =
+			xf86SetIntOption(pInfo->options, "ZoomDistance",
+					 zoom_distance);
+
+		common->wcmGestureParameters.wcmScrollDistance =
+			xf86SetIntOption(pInfo->options, "ScrollDistance",
+					 scroll_distance);
+
+		common->wcmGestureParameters.wcmMaxScrollFingerSpread =
+			common->wcmMaxTouchX *
+			(WCM_BAMBOO3_SCROLL_SPREAD_DISTANCE / WCM_BAMBOO3_MAXX);
+	}
+
+
+	return TRUE;
+}
+
 /* vim: set noexpandtab tabstop=8 shiftwidth=8: */
